@@ -253,7 +253,7 @@ fn can_model_linearizable_register() {
         Deliver { src: Id::from(0), dst: Id::from(1), msg: Internal(Record(6, (1, Id::from(1)), 'B')) },
         Deliver { src: Id::from(1), dst: Id::from(0), msg: Internal(AckRecord(6)) },
     ]);
-    assert_eq!(checker.generated_count(), 544);
+    assert_eq!(checker.unique_state_count(), 544);
 
     // DFS
     let checker = AbdModelCfg {
@@ -275,7 +275,7 @@ fn can_model_linearizable_register() {
         Deliver { src: Id::from(0), dst: Id::from(1), msg: Internal(Record(6, (1, Id::from(1)), 'B')) },
         Deliver { src: Id::from(1), dst: Id::from(0), msg: Internal(AckRecord(6)) },
     ]);
-    assert_eq!(checker.generated_count(), 544);
+    assert_eq!(checker.unique_state_count(), 544);
 }
 
 fn main() {
