@@ -27,7 +27,7 @@ pub use visitor::*;
               Consider calling spawn_bfs() or spawn_dfs()."]
 pub struct CheckerBuilder<M: Model> {
     model: M,
-    target_generated_count: Option<NonZeroUsize>,
+    target_state_count: Option<NonZeroUsize>,
     thread_count: usize,
     visitor: Option<Box<dyn CheckerVisitor<M> + Send + Sync>>,
 }
@@ -35,7 +35,7 @@ impl<M: Model> CheckerBuilder<M> {
     pub(crate) fn new(model: M) -> Self {
         Self {
             model,
-            target_generated_count: None,
+            target_state_count: None,
             thread_count: 1,
             visitor: None,
         }
@@ -136,8 +136,8 @@ impl<M: Model> CheckerBuilder<M> {
 
     /// Sets the number of states that the checker should aim to generate. For performance reasons
     /// the checker may exceed this number, but it will never generate fewer states if more exist.
-    pub fn target_generated_count(self, target_generated_count: usize) -> Self {
-        Self { target_generated_count: NonZeroUsize::new(target_generated_count), .. self }
+    pub fn target_state_count(self, count: usize) -> Self {
+        Self { target_state_count: NonZeroUsize::new(count), .. self }
     }
 
     /// Sets the number of threads available for model checking. For maximum performance this
@@ -160,8 +160,13 @@ pub trait Checker<M: Model> {
     /// Returns a reference to this checker's [`Model`].
     fn model(&self) -> &M;
 
-    /// Indicates how many states have been generated.
-    fn generated_count(&self) -> usize;
+    /// Indicate how many states have been generated including repeats. Always greater than or
+    /// equal to [`Checker::unique_state_count`].
+    fn state_count(&self) -> usize;
+
+    /// Indicates how many unique states have been generated. Always less than or equal to
+    /// [`Checker::state_count`].
+    fn unique_state_count(&self) -> usize;
 
     /// Returns a map from property name to corresponding "discovery" (indicated
     /// by a [`Path`]).
@@ -191,12 +196,15 @@ pub trait Checker<M: Model> {
         // Start with the checking status.
         let method_start = Instant::now();
         while !self.is_done() {
-            let _ = writeln!(w, "Checking. generated={}", self.generated_count());
+            let _ = writeln!(w, "Checking. states={}, unique={}",
+                             self.state_count(),
+                             self.unique_state_count());
             std::thread::sleep(std::time::Duration::from_millis(1_000));
         }
-        let _ = writeln!(w, "Done. generated={}, sec={}",
-                 self.generated_count(),
-                 method_start.elapsed().as_secs());
+        let _ = writeln!(w, "Done. states={}, unique={}, sec={}",
+                         self.state_count(),
+                         self.unique_state_count(),
+                         method_start.elapsed().as_secs());
 
         // Finish with a discovery summary.
         for (name, path) in self.discoveries() {
@@ -423,8 +431,8 @@ mod test_report {
         let output = String::from_utf8(written).unwrap();
         assert!(
             output.starts_with("\
-                Checking. generated=1\n\
-                Done. generated=12, sec="),
+                Checking. states=1, unique=1\n\
+                Done. states=15, unique=12, sec="),
             "Output did not start as expected (see test). output={:?}`", output);
         assert!(
             output.ends_with("\
@@ -441,8 +449,8 @@ mod test_report {
         let output = String::from_utf8(written).unwrap();
         assert!(
             output.starts_with("\
-                Checking. generated=1\n\
-                Done. generated=55, sec="),
+                Checking. states=1, unique=1\n\
+                Done. states=55, unique=55, sec="),
             "Output did not start as expected (see test). output={:?}`", output);
         assert!(
             output.ends_with("\
