@@ -13,7 +13,8 @@ use std::collections::VecDeque;
 struct StatusView {
     done: bool,
     model: String,
-    generated: usize,
+    state_count: usize,
+    unique_state_count: usize,
     properties: Vec<(Expectation,
                      String,           // name
                      Option<String>)>, // encoded path to discovery
@@ -141,7 +142,8 @@ where M: Model,
     let status = StatusView {
         model: std::any::type_name::<M>().to_string(),
         done: checker.is_done(),
-        generated: checker.generated_count(),
+        state_count: checker.state_count(),
+        unique_state_count: checker.unique_state_count(),
         properties: checker.model().properties().into_iter()
             .map(|p| (
                     p.expectation,
@@ -386,7 +388,8 @@ mod test {
             "stateright::actor::model::ActorModel<\
                  stateright::actor::actor_test_util::ping_pong::PingPongActor, \
                  stateright::actor::actor_test_util::ping_pong::PingPongCfg, (u32, u32)>");
-        assert_eq!(status.generated, 5);
+        assert_eq!(status.state_count, 5);
+        assert_eq!(status.unique_state_count, 5);
         assert_eq!(status.properties, vec![
             (Expectation::Always, "delta within 1".to_string(), None),
             (Expectation::Sometimes, "can reach max".to_string(), Some(
